====================================
Transmogrify |version| documentation
====================================

Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   getting_started
   installation
   templatetag
   webserver_integration/index
   reference/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

